@@ -69,7 +69,7 @@ class CS50:
         auth_request = c.begin('https://id.cs50.net')
         
         # simple registration fields
-        if (fields and len(fields) > 0)
+        if len(fields) > 0:
             sreg_request = sreg.SRegRequest(optional=fields, required=['key'])
             auth_request.addExtension(sreg_request)
             
